import os
import sys
import site

os.environ['DJANGO_SETTINGS_MODULE'] = 'demo.settings'

SITE_ROOT = os.path.dirname(os.path.dirname( __file__ ))
site.addsitedir( SITE_ROOT + '/venv/local/lib/python2.7/site-packages' )

sys.path.append( SITE_ROOT )

activate_env=os.path.expanduser(SITE_ROOT + "/venv/bin/activate_this.py")
execfile(activate_env, dict(__file__=activate_env))

import django.core.handlers.wsgi
application = django.core.handlers.wsgi.WSGIHandler()



__prog__     = "bsct"
__pkg_name__ = "django-bootstrap-crud-templates"
__author__   = "Z. Alem"
__licence__  = "GNU General Public License v3 (GPLv3)"
__version__  = "1.0.1"
__desc__     = "A repository of Bootstrap CRUD templates for Django."



from django.forms.models import model_to_dict as django_m2d
from django.template import Library

register = Library()

# -------------------------
# Template Tags
# -------------------------

# CDN Resources
# -------------------------

@register.simple_tag()
def netdna_cdn( path ):
    """
    Returns a link to the named NetDNA-hosted CSS resource.
    """
    return '<link href="//netdna.bootstrapcdn.com/%s" rel="stylesheet">' % path

@register.simple_tag()
def bootstrap_cdn():
    """
    Returns a link to a CDN-hosted Bootstrap minified CSS file.
    """
    return netdna_cdn('twitter-bootstrap/2.3.2/css/bootstrap-combined.min.css')

@register.simple_tag()
def bootswatch_cdn( theme ):
    """
    Returns a link to the named CDN-hosted Bootstrap Swatch theme.
    """
    if theme.lower() in [
            "amelia","cerulean","cosmo","cyborg","flatly",
            "journal","readable","simplex","slate","spacelab",
            "spruce","superhero","united"
    ]:
        return netdna_cdn( "bootswatch/2.3.2/%s/bootstrap.min.css" % theme )
    raise Exception( "Unrecognized bootswatch theme: '%s'." % theme )


# Meta-data Extractors 
# -------------------------

@register.simple_tag()
def get_verbose_name( object ):
    """
    Returns the verbose name for a model.
    """
    return object._meta.verbose_name

@register.simple_tag()
def get_verbose_name_plural( object ):
    """
    Returns the verbose pluralized name for a model.
    """
    return object._meta.verbose_name_plural

# -------------------------
# Filters
# -------------------------

@register.filter
def model_to_dict( object ):
    """
    Converts a model into a dictionary of its fields and values.
    """
    return django_m2d( object )



from django.core.urlresolvers import reverse
from django.db import models

class Widget( models.Model ):
    name = models.CharField( max_length = 10 )
    sku  = models.IntegerField()
    
    def get_absolute_url( self ):
        return reverse( 'widget', kwargs = {'pk' : self.pk } )

    def get_create_url( self ):
        return reverse( 'widget_create' )

    def get_list_url( self ):
        return reverse( 'widgets' )

    def get_delete_url( self ):
        return reverse( 'widget_delete', kwargs = {'pk' : self.pk } )

    def get_update_url( self ):
        return reverse( 'widget_update', kwargs = {'pk' : self.pk } )

    def __unicode__( self ):
        return '%s' % ( self.name )
    
    class Meta:
        verbose_name = "Widget"
        verbose_name_plural = "Widgets"



from django.conf.urls import patterns, include, url
from django.core.urlresolvers import reverse_lazy
from django.views import generic
from crud import models

urlpatterns = patterns('',
    url(
        r'widget/add/$', generic.CreateView.as_view( 
            model=models.Widget,
            template_name = 'bsct/plain/form.html',
        ),
        name = 'widget_create'
    ),

    url(
        r'widget/update/(?P<pk>\d+)$', generic.UpdateView.as_view( 
            model=models.Widget,
            template_name = 'bsct/plain/form.html',
        ),
        name = 'widget_update'
    ),

    url(
        r'widget/list$', generic.ListView.as_view( 
            model=models.Widget,
            template_name = 'bsct/plain/list.html',
        ), 
        name = 'widgets'
    ),

    url(
        r'widget/(?P<pk>\d+)$', generic.DetailView.as_view(
            model=models.Widget,
            template_name = 'bsct/plain/detail.html',
        ),
        name = 'widget'
    ),

    url(
        r'widget/delete/(?P<pk>\d+)$', generic.DeleteView.as_view( 
            model=models.Widget,
            template_name = 'bsct/plain/confirm_delete.html',
            success_url = reverse_lazy('widgets')
        ),
        name = 'widget_delete'
    ),
)



from setuptools import setup, find_packages
from os.path import dirname
import bsct

setup(
    name    = '%s' % bsct.__pkg_name__,
    version = bsct.__version__,
    author  = bsct.__author__,
    author_email = "alem@cidola.com",
    description  = bsct.__desc__,
    license      = bsct.__licence__,
    keywords     = "django, templates. bootstrap, bootstrap templates, crud templates",
    url          = "http://packages.python.org/%s" % bsct.__pkg_name__,
    packages     = find_packages(),
    include_package_data = True,
    long_description = open('README.rst').read(),
    classifiers  = [
         'Environment :: Web Environment',
         'Framework :: Django',
         'Intended Audience :: Developers',
         "License :: OSI Approved :: %s" % bsct.__licence__,
         'Operating System :: OS Independent',
         'Programming Language :: Python',
         'Programming Language :: Python :: 2.7',
         'Topic :: Internet :: WWW/HTTP',
         'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
